@@ -19,7 +19,8 @@ class DiarioquoteCommand(rc.Command):
             entry_id = int(args[0].lstrip("#"))
         except ValueError:
             raise rc.CommandError("L'id che hai specificato non è valido.")
-        entry: Diario = await ru.asyncify(data.session.query(self.alchemy.get(Diario)).get, entry_id)
+        async with data.session_acm() as session:
+            entry: Diario = await ru.asyncify(session.query(self.alchemy.get(Diario)).get, entry_id)
         if entry is None:
             raise rc.CommandError("Nessuna riga con quell'id trovata.")
         await data.reply(f"ℹ️ {entry}")
