@@ -13,19 +13,20 @@ class TreasureCommand(rc.Command):
     syntax: str = "{code}"
 
     async def run(self, args: rc.CommandArgs, data: rc.CommandData) -> None:
-        author = await data.get_author(error_if_none=True)
-        code = args[0].lower()
-
         TreasureT = self.alchemy.get(Treasure)
 
-        treasure = await ru.asyncify(data.session.query(TreasureT).get, code)
-        if treasure is None:
-            raise rc.UserError("Non esiste nessun Treasure con quel codice.")
-        if treasure.redeemed_by is not None:
-            raise rc.UserError(f"Quel tesoro è già stato riscattato da {treasure.redeemed_by}.")
+        async with data.session_acm() as session:
+            author = await data.find_author(session=session, required=True)
+            code = args[0].lower()
 
-        treasure.redeemed_by = author
-        await data.session_commit()
+            treasure = await ru.asyncify(session.query(TreasureT).get, code)
+            if treasure is None:
+                raise rc.UserError("Non esiste nessun Treasure con quel codice.")
+            if treasure.redeemed_by is not None:
+                raise rc.UserError(f"Quel tesoro è già stato riscattato da {treasure.redeemed_by}.")
+
+            treasure.redeemed_by = author
+            await ru.asyncify(session.commit)
         await FiorygiTransaction.spawn_fiorygi(data,
                                                author,
                                                treasure.value,
